package com.sf.deploy.mapper;

import java.util.List;
import com.sf.deploy.domain.SysApkInfo;

/**
 * 安装包管理（新）Mapper接口
 * 
 * @author ztzh
 * @date 2024-04-11
 */
public interface SysApkInfoMapper 
{
    /**
     * 查询安装包管理（新）
     * 
     * @param id 安装包管理（新）主键
     * @return 安装包管理（新）
     */
    public SysApkInfo selectSysApkInfoById(Long id);

    /**
     * 查询安装包管理（新）列表
     * 
     * @param sysApkInfo 安装包管理（新）
     * @return 安装包管理（新）集合
     */
    public List<SysApkInfo> selectSysApkInfoList(SysApkInfo sysApkInfo);

    /**
     * 新增安装包管理（新）
     * 
     * @param sysApkInfo 安装包管理（新）
     * @return 结果
     */
    public int insertSysApkInfo(SysApkInfo sysApkInfo);

    /**
     * 修改安装包管理（新）
     * 
     * @param sysApkInfo 安装包管理（新）
     * @return 结果
     */
    public int updateSysApkInfo(SysApkInfo sysApkInfo);

    /**
     * 删除安装包管理（新）
     * 
     * @param id 安装包管理（新）主键
     * @return 结果
     */
    public int deleteSysApkInfoById(Long id);

    /**
     * 批量删除安装包管理（新）
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysApkInfoByIds(Long[] ids);
}
